@@ -35,6 +35,7 @@
 
 #include <libgnomeprint/private/gnome-print-private.h>
 
+#include "gnome-print-preview-private.h"
 #include "gnome-print-i18n.h"
 #include "gnome-print-job-preview.h"
 
@@ -90,10 +91,13 @@ struct _GPMPPrivate {
 	GtkWidget *scrolled_window;
 	GtkWidget *last;
 	GnomeCanvas *canvas;
+	GnomeCanvasItem *page;
 
 	gint current_page;
 	gint pagecount;
 
+	/* Strict theme compliance [#96802] */
+	gboolean theme_compliance;
 };
 
 static void gpmp_parse_layout (GnomePrintJobPreview *mp);
@@ -135,6 +139,8 @@ render_page (GnomePrintJobPreview *mp, gint page)
 
 	config = gnome_print_job_get_config (priv->job);
 	priv->preview = gnome_print_preview_new_full (config, priv->canvas, transform, &region);
+	gnome_print_preview_theme_compliance (GNOME_PRINT_PREVIEW (priv->preview),
+					      priv->theme_compliance);
 	gnome_print_config_unref (config);
 
 	gnome_print_job_render_page (priv->job, priv->preview, page, TRUE);
@@ -513,6 +519,26 @@ preview_canvas_key (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	return TRUE;
 }
 
+static void
+canvas_style_changed_cb (GtkWidget *canvas, GtkStyle *ps, GnomePrintJobPreview *mp)
+{
+	GPMPPrivate *priv;
+	GtkStyle *style;
+	gint32 border_color;
+	gint32 page_color;
+
+	priv = (GPMPPrivate *) mp->priv;
+
+	style = gtk_widget_get_style (GTK_WIDGET (canvas));
+	page_color = GPP_COLOR_RGBA (style->base [GTK_STATE_NORMAL], 0xff);
+	border_color = GPP_COLOR_RGBA (style->text [GTK_STATE_NORMAL], 0xff);
+
+	gnome_canvas_item_set (priv->page,
+			       "fill_color_rgba", page_color,
+			       "outline_color_rgba", border_color,
+			       NULL);
+}
+	
 static void
 create_preview_canvas (GnomePrintJobPreview *mp)
 {
@@ -552,22 +578,35 @@ create_preview_canvas (GnomePrintJobPreview *mp)
 	priv->preview = gnome_print_preview_new (config, priv->canvas);
 	gnome_print_config_unref (config);
 
+	if (priv->theme_compliance) {
+		g_signal_connect (G_OBJECT (priv->canvas), "style_set",
+				  G_CALLBACK (canvas_style_changed_cb), mp);
+	}
+	
 	/*
 	 * Now add some padding above and below and put a simulated
 	 * page on the background
 	 */
-
 	item = gnome_canvas_item_new (gnome_canvas_root (priv->canvas),
 				      GNOME_TYPE_CANVAS_RECT,
-				      "x1", 0.0, "y1", 0.0, "x2", (gdouble) mp->paw, "y2", (gdouble) mp->pah,
+				      "x1", 0.0,
+				      "y1", 0.0,
+				      "x2", (gdouble) mp->paw,
+				      "y2", (gdouble) mp->pah,
 				      "fill_color", "white",
 				      "outline_color", "black",
-				      "width_pixels", 1, NULL);
+				      "width_pixels", 1,
+				      NULL);
+	priv->page = item;
 	gnome_canvas_item_lower_to_bottom (item);
 	item = gnome_canvas_item_new (gnome_canvas_root (priv->canvas),
 				      GNOME_TYPE_CANVAS_RECT,
-				      "x1", 3.0, "y1", 3.0, "x2", (gdouble) mp->paw + 3, "y2", (gdouble) mp->pah + 3,
-				      "fill_color", "black", NULL);
+				      "x1", 3.0,
+				      "y1", 3.0,
+				      "x2", (gdouble) mp->paw + 3,
+				      "y2", (gdouble) mp->pah + 3,
+				      "fill_color", "black",
+				      NULL);
 	gnome_canvas_item_lower_to_bottom (item);
 	gnome_canvas_set_scroll_region (priv->canvas, 0 - PAGE_PAD, 0 - PAGE_PAD, mp->paw + PAGE_PAD, mp->pah + PAGE_PAD);
 
@@ -630,10 +669,6 @@ create_toplevel (GnomePrintJobPreview *mp)
 	width  = MIN (mp->paw + PAGE_PAD * 3, gdk_screen_width () - 40);
 	height = MIN (mp->pah + PAGE_PAD * 3, gdk_screen_height () - 40);
 
-	/* FIXME: This call is depreacated, left over from port to 2.0 (Chema)  */
-#if 0	
-	gtk_window_set_policy (GTK_WINDOW (mp), TRUE, TRUE, FALSE);
-#endif	
 	gtk_widget_set_size_request (GTK_WIDGET (mp), width, height);
 
 	/* This is not very beautiful, but works for now */
@@ -756,10 +791,16 @@ static void
 gnome_print_job_preview_init (GnomePrintJobPreview *mp)
 {
 	GPMPPrivate *priv;
-
+	const gchar *env_theme_variable;
+	
 	mp->priv = priv = g_new0 (GPMPPrivate, 1);
 	priv->current_page = -1;
 
+	priv->theme_compliance = FALSE;
+	env_theme_variable = g_getenv("GP_PREVIEW_STRICT_THEME");
+	if (env_theme_variable && env_theme_variable [0])
+		priv->theme_compliance = TRUE;
+
 	/* Main VBox */
 	mp->vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (mp->vbox);
